"use strict";

function pathEasing(pathData, options) {
    var window = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : window;
    options = options || {};
    var sampleCount = options.samples === undefined ? 300 : options.samples;
    var height = options.height === undefined ? 100 : options.height;
    var width = options.width === undefined ? 100 : options.width;
    var path = window.document.createElementNS("http://www.w3.org/2000/svg", "path");
    path.setAttribute("d", pathData);
    var pathLength = path.getTotalLength();
    var sampleCountPct = 1 / sampleCount;
    var xSamples = new Float64Array(sampleCount);
    var ySamples = new Float64Array(sampleCount);
    var preComputeStart = window.performance.now();
    for (var i = 0; i < sampleCount; i++) {
        var point = path.getPointAtLength(sampleCountPct * i * pathLength);
        xSamples[i] = point.x / width;
        ySamples[i] = 1 - point.y / height;
    }
    var preComputeEnd = window.performance.now();
    function tween(t) {
        for (var n = 0; n < xSamples.length; n++) {
            if (xSamples[n] == t || xSamples[n] < t && xSamples[n + 1] > t) {
                return ySamples[n];
            }
        }
        return t;
    }
    tween.path = path;
    tween.preComputeTime = preComputeEnd - preComputeStart;
    tween.sampleCount = sampleCount;
    return tween;
}

module.exports = pathEasing;